# DudeProject - DudeSec v0.0.3

[![Build Status](https://travis-ci.org/joemccann/dillinger.svg?branch=master)](https://test.pypi.org/project/dudesec/1.0.0/)


O projeto Dude tem como objetivo criar librarys para diversas funcionalidades em diversas linguagens, portanto, um de seus módulos é o de Seguranca Cibernética.
Neste repositório, iremos abranger os seguintes objetivos:

  - Segurança e monitoramento de redes.
  - Segurança e monitoramento de servidores.
  - Segurança e monitoramento de aplicações.

Para acompanhar a library, usamos a seguinte lógica: Na branch master, estará presente a versão mais atual. Nas outras branchs, estarão disponibilizadas o código de acordo com a versão.

# Ferramentas presentes na versão atual:

  - Scanner de portas abertas a partir de um range pré definido. (v0.0.1)
  - Monitoramento de aplicações WEB através de webscrapping. (v0.0.2)
  - Monitoramento de dominios.(v0.0.2)
  - Monitoramento de aplicações APIS.(v0.0.3)
  - Implementação de WEBHOOK para atualizações. (v0.0.4)
  - Codificação e decodificação de textos usando base64.(v0.0.4)

> Lembrando que, o repositório está e sempre estará aberto a novas opiniões
> e ponto de vista. Portanto, ao requisitar alguma atualização lembre-se
> que esta lib é uma ajuda, não um direito tenha educação e simpatia.

# Ideias para possiveis atualizações:

- Criptografia de texto
- Gerador de WordList para ataques brute force
- Captura de tela de website por webscrapping

### Como instalar

Para usar esta library com o Python é bem simples, basta instala-la usando o gerenciador de pacotes pipy , com o seguinte comando:

```sh
$ pip install dudsec
```

E após isto, importa-lo desta maneira:

```sh
import * from dudesec
```